OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privadesa",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centre de privacitat us mostra a on s'emmagatzemen les vostres dades i qui pot accedir-hi, ja sia perquè vau compartir amb ell/ella o perquè són usuaris administradors.",
    "Add external admin" : "Afegeix un administrador extern",
    "Your files are not protected by encryption." : "Els vostres fitxers no estan protegits per xifratge.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Els vostres fitxers estan xifrats amb {linkopen}xifratge del costat del servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Aquest servidor està protegit amb xifratge complet del disc.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Els vostres fitxers estan xifrats amb {linkopen}xifratge del costat del servidor ↗{linkclose}. A més, aquest servidor està protegit amb el xifratge complet del disc.",
    "This server is using full-disk-encryption." : "Aquest servidor està fent servir xifratge complet de disc.",
    "Your data is located in: " : "Les vostres dades es troben a: ",
    "The admin hasn't selected the location of the server yet." : "L'administrador encara no ha seleccionat la ubicació del servidor.",
    "Please select a country" : "Seleccioneu un país",
    "You don't have any shares with individual users." : "No teniu cap compartició amb usuaris individuals.",
    "Somaliland" : "Somalilàndia",
    "United Arab Emirates" : "Emirats Àrabs Units",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albània",
    "Armenia" : "Armènia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Àustria",
    "Australia" : "Austràlia",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegowina" : "Bòsnia i Hercegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgària",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahames",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorússia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Democratic Republic of the Congo" : "Repúplica Democràtica del Congo",
    "Central African Republic" : "República Centreafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suïssa",
    "Cote d'Ivoire" : "Costa d'Ivori",
    "Chile" : "Xile",
    "Cameroon" : "Camerun",
    "China" : "Xina",
    "Colombia" : "Colòmbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Xipre",
    "Czech" : "República Txeca",
    "Germany" : "Alemanya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algèria",
    "Ecuador" : "Equador",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "West Sahara" : "Sàhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanya",
    "Ethiopia" : "Etiòpia",
    "Finland" : "Finlàndia",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Illes Malvines",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regne Unit",
    "Georgia" : "Geòrgia",
    "Ghana" : "Ghana",
    "Greenland" : "Groenlàndia",
    "Gambia" : "Gàmbia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Equatorial",
    "Greece" : "Grècia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Hondures",
    "Croatia" : "Croàcia",
    "Haiti" : "Haití",
    "Hungary" : "Hongria",
    "Indonesia" : "Indonèsia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "Índia",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Itàlia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordània",
    "Japan" : "Japó",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirguizistan",
    "Cambodia" : "Cambodja",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Líban",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letònia",
    "Libya" : "Líbia",
    "Morocco" : "Marroc",
    "Moldova" : "Moldàvia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedònia",
    "Mali" : "Mali",
    "Myanmar" : "Birmània",
    "Mongolia" : "Mongòlia",
    "Mauritania" : "Mauritània",
    "Malawi" : "Malawi",
    "Mexico" : "Mèxic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledònia",
    "Niger" : "Níger",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Països Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Perú",
    "Papua New Guinea" : "Papua Nova Guinea",
    "Philippines" : "Filipines",
    "Pakistan" : "Pakistan",
    "Poland" : "Polònia",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Sèrbia",
    "Russia" : "Rússia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Aràbia Saudita",
    "Solomon Islands" : "Illes Salomó",
    "Sudan" : "Sudan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapur",
    "Slovenia" : "Eslovènia",
    "Slovakia" : "Eslovàquia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somàlia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudan del Sud",
    "El Salvador" : "El Salvador",
    "Syria" : "Síria",
    "Swaziland" : "Swazilàndia",
    "Chad" : "Txad",
    "Fr. S. Antarctic Lands" : "Terres Australs i Antàrtiques Franceses",
    "Togo" : "Togo",
    "Thailand" : "Tailàndia",
    "Tajikistan" : "Tadjikistan",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunísia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat i Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzània",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Uganda",
    "United States" : "Estats Units",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Veneçuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iemen",
    "South Africa" : "Sud-àfrica",
    "Zambia" : "Zàmbia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "El vostre compte de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Les vostres dades representen qui sou i poden ser objecte d’abús fàcilment. A Nextcloud creiem que teniu dret a decidir què passa amb les vostres dades. Nextcloud protegeix els vostres drets tal com es defineix al Manifest de Dades de l'Usuari (User Data Manifesto)!",
    "User Data Manifesto 2.0" : "Manifest de Dades de l'Usuari 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definició de drets bàsics per a que les persones puguin controlar les seves pròpies dades en l’era d'Internet",
    "Control" : "Control",
    "over user data access" : "sobre l’accés a les dades dels usuaris",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Les dades carregades de manera explícita i voluntària per un usuari haurien d'estar sota el control definitiu de l'usuari. Els usuaris haurien de poder decidir a qui concedir accés directe a les seves dades i amb quins permisos i llicències s’hauria de concedir.",
    "Knowledge" : "Coneixement",
    "of how the data is stored" : "de com s'emmagatzemen les dades",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quan es carreguen les dades a un proveïdor de serveis específic, els usuaris haurien de ser informats sobre el lloc on el proveïdor de serveis específic emmagatzema les dades, per quant de temps, sota quina jurisdicció opera el proveïdor de serveis específic i quines lleis s'apliquen.",
    "Freedom" : "Llibertat",
    "to choose a platform" : "per triar una plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Els usuaris sempre han de poder extreure les seves dades del servei en qualsevol moment sense experimentar cap bloqueig per part del proveïdor. Per garantir això, calen estàndards oberts per a formats i protocols.",
    "Learn more ↗" : "Més informació ↗",
    "Where is your data?" : "On són les vostres dades?",
    "Who has access to your data?" : "Qui té accés a les vostres dades?",
    "Administrators" : "Administradors",
    "People you shared with" : "Persones amb les quals heu compartit",
    "Privacy policy" : "Política de privadesa",
    "Read the privacy policy." : "Llegiu la política de privadesa.",
    "Encryption" : "Xifratge"
},
"nplurals=2; plural=(n != 1);");
